\name{variog.env}

\alias{variog.env}

%- Also NEED an `\alias' for EACH other topic documented here.

\title{Envelops for Empirical Variograms}

\description{
  This function computes emvelops for empirical variograms by simulating
  data for given parameters.
}

\usage{
variog.env(obj.variog, coords, model.pars, nsim=99,
           messages.screen=TRUE)
}

%- maybe also `usage' for other objects documented here.

\arguments{
  \item{obj.variog}{an object returned by the function \code{\link{variogram}}}
  \item{coords}{an \eqn{n \times 2}{n x 2} matrix containing
    coordinates of the \eqn{n} data locations in each row.}
  \item{model.pars}{a list with model
    specification/parameters. Typically an output of \code{\link{likfit}},
    \code{\link{wlsfit}} or \code{\link{olsfit}}, 
  \item{nsim}{number of simulations to compute the envelope. Defaults to
  99.}
  \item{messages.screen}{if \code{TRUE}, the default, status messages
    are printed while the function is running.}
}

\details{
  The envelops are computed assuming a (transformed) Gaussian Random
  Field. Simulations are generated at the data location. For each
  simulations the
  empirical variogram is computed at the same lags as the data variogram.
  The maximum and minimum values of the simulated data
  variograms at each lag defines the envelops.
}

\value{
  A list with the components:
  \item{u}{a vector with distances.}
  \item{v.lower}{a vector with the minimum variogram values at each
    distance in \code{u}, across the simulations.}
  \item{v.upper}{a vector with the maximum variogram values at each
    distance in \code{u}, across the simulations.}
}

\references{
  Further information about \code{geoR/geoS} can be found at:\cr
  \url{http://www.maths.lancs.ac.uk/~ribeiro/geoR.html}
}

\author{Paulo Justiniano Ribeiro Jr. \email{paulojus@est.ufpr.br} \cr
  Peter J. Diggle \email{p.diggle@lancaster.ac.uk}.
}

%\note{ ~~further notes~~ }

\seealso{\code{\link{variog}}, \code{\link{plot.variogram}}, \code{\link{likfit}},
    \code{\link{wlsfit}}, \code{\link{olsfit}}, .}

\examples{
data(s100)
ml <- likfit(s100,ini=c(0.5,0.5),fix.nugget=T)
vario <- variog(s100, max.dist=1)
env <- variog.env(vario,s100$coords,model.pars=ml)
plot(vario,envelope=env)

}

\keyword{spatial}%-- one or more ...

